From: agk@sourceware.org <agk@sourceware.org>
To: lvm-devel@redhat.com
Subject: LVM2 ./WHATS_NEW lib/mirror/mirrored.c
Date: 16 Jan 2008 15:24:25 -0000 [thread overview]
Message-ID: <20080116152425.22020.qmail@sourceware.org> (raw)
CVSROOT: /cvs/lvm2
Module name: LVM2
Changes by: agk at sourceware.org 2008-01-16 15:24:25
Modified files:
. : WHATS_NEW
lib/mirror : mirrored.c
Log message:
Don't use block_on_error with mirror targets above version 1.12.
Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/WHATS_NEW.diff?cvsroot=lvm2&r1=1.760&r2=1.761
http://sourceware.org/cgi-bin/cvsweb.cgi/LVM2/lib/mirror/mirrored.c.diff?cvsroot=lvm2&r1=1.46&r2=1.47
--- LVM2/WHATS_NEW 2008/01/15 20:37:49 1.760
+++ LVM2/WHATS_NEW 2008/01/16 15:24:25 1.761
@@ -1,5 +1,6 @@
Version 2.02.30 -
===================================
+ Don't use block_on_error with mirror targets above version 1.12.
Update vgsplit to include vgcreate-style options when new VG is destination.
Update vgsplit to accept existing VG as destination.
lvconvert waits for completion of initial sync by default.
--- LVM2/lib/mirror/mirrored.c 2007/08/20 20:55:27 1.46
+++ LVM2/lib/mirror/mirrored.c 2008/01/16 15:24:25 1.47
@@ -348,14 +348,14 @@
_mirrored_present = target_present("mirror", 1);
/*
* block_on_error available with mirror target >= 1.1
* or with 1.0 in RHEL4U3 driver >= 4.5
*/
/* FIXME Move this into libdevmapper */
if (target_version("mirror", &maj, &min, &patchlevel) &&
maj == 1 &&
- (min >= 1 ||
+ ((min >= 1 && min <= 11) ||
(min == 0 && driver_version(vsn, sizeof(vsn)) &&
sscanf(vsn, "%u.%u.%u", &maj2, &min2, &patchlevel2) == 3 &&
maj2 == 4 && min2 == 5 && patchlevel2 == 0))) /* RHEL4U3 */
next reply other threads:[~2008-01-16 15:24 UTC|newest]
Thread overview: 8+ messages / expand[flat|nested] mbox.gz Atom feed top
2008-01-16 15:24 agk [this message]
-- strict thread matches above, loose matches on Subject: below --
2008-07-31 14:43 LVM2 ./WHATS_NEW lib/mirror/mirrored.c agk
2009-11-18 16:48 mbroz
2010-05-24 16:30 agk
2010-12-01 13:01 zkabelac
2011-06-17 14:17 zkabelac
2012-02-13 11:07 zkabelac
2012-02-23 22:30 zkabelac
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20080116152425.22020.qmail@sourceware.org \
--to=agk@sourceware.org \
--cc=lvm-devel@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -348,14 +348,14 @@
_mirrored_present = target_present("mirror", 1);
/*
- * block_on_error available with mirror target >= 1.1
+ * block_on_error available with mirror target >= 1.1 and <= 1.11
* or with 1.0 in RHEL4U3 driver >= 4.5
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.